[−][src]Enum unicode_types::alchemical_symbols::AlchemicalSymbols
An enum to represent all characters in the AlchemicalSymbols block.
Variants
AlchemicalSymbolForQuintessence\u{1f700}: '🜀'
AlchemicalSymbolForAir\u{1f701}: '🜁'
AlchemicalSymbolForFire\u{1f702}: '🜂'
AlchemicalSymbolForEarth\u{1f703}: '🜃'
AlchemicalSymbolForWater\u{1f704}: '🜄'
AlchemicalSymbolForAquafortis\u{1f705}: '🜅'
AlchemicalSymbolForAquaRegia\u{1f706}: '🜆'
AlchemicalSymbolForAquaRegiaDash2\u{1f707}: '🜇'
AlchemicalSymbolForAquaVitae\u{1f708}: '🜈'
AlchemicalSymbolForAquaVitaeDash2\u{1f709}: '🜉'
AlchemicalSymbolForVinegar\u{1f70a}: '🜊'
AlchemicalSymbolForVinegarDash2\u{1f70b}: '🜋'
AlchemicalSymbolForVinegarDash3\u{1f70c}: '🜌'
AlchemicalSymbolForSulfur\u{1f70d}: '🜍'
AlchemicalSymbolForPhilosophersSulfur\u{1f70e}: '🜎'
AlchemicalSymbolForBlackSulfur\u{1f70f}: '🜏'
AlchemicalSymbolForMercurySublimate\u{1f710}: '🜐'
AlchemicalSymbolForMercurySublimateDash2\u{1f711}: '🜑'
AlchemicalSymbolForMercurySublimateDash3\u{1f712}: '🜒'
AlchemicalSymbolForCinnabar\u{1f713}: '🜓'
AlchemicalSymbolForSalt\u{1f714}: '🜔'
AlchemicalSymbolForNitre\u{1f715}: '🜕'
AlchemicalSymbolForVitriol\u{1f716}: '🜖'
AlchemicalSymbolForVitriolDash2\u{1f717}: '🜗'
AlchemicalSymbolForRockSalt\u{1f718}: '🜘'
AlchemicalSymbolForRockSaltDash2\u{1f719}: '🜙'
AlchemicalSymbolForGold\u{1f71a}: '🜚'
AlchemicalSymbolForSilver\u{1f71b}: '🜛'
AlchemicalSymbolForIronOre\u{1f71c}: '🜜'
AlchemicalSymbolForIronOreDash2\u{1f71d}: '🜝'
AlchemicalSymbolForCrocusOfIron\u{1f71e}: '🜞'
AlchemicalSymbolForRegulusOfIron\u{1f71f}: '🜟'
AlchemicalSymbolForCopperOre\u{1f720}: '🜠'
AlchemicalSymbolForIronDashCopperOre\u{1f721}: '🜡'
AlchemicalSymbolForSublimateOfCopper\u{1f722}: '🜢'
AlchemicalSymbolForCrocusOfCopper\u{1f723}: '🜣'
AlchemicalSymbolForCrocusOfCopperDash2\u{1f724}: '🜤'
AlchemicalSymbolForCopperAntimoniate\u{1f725}: '🜥'
AlchemicalSymbolForSaltOfCopperAntimoniate\u{1f726}: '🜦'
AlchemicalSymbolForSublimateOfSaltOfCopper\u{1f727}: '🜧'
AlchemicalSymbolForVerdigris\u{1f728}: '🜨'
AlchemicalSymbolForTinOre\u{1f729}: '🜩'
AlchemicalSymbolForLeadOre\u{1f72a}: '🜪'
AlchemicalSymbolForAntimonyOre\u{1f72b}: '🜫'
AlchemicalSymbolForSublimateOfAntimony\u{1f72c}: '🜬'
AlchemicalSymbolForSaltOfAntimony\u{1f72d}: '🜭'
AlchemicalSymbolForSublimateOfSaltOfAntimony\u{1f72e}: '🜮'
AlchemicalSymbolForVinegarOfAntimony\u{1f72f}: '🜯'
AlchemicalSymbolForRegulusOfAntimony\u{1f730}: '🜰'
AlchemicalSymbolForRegulusOfAntimonyDash2\u{1f731}: '🜱'
AlchemicalSymbolForRegulus\u{1f732}: '🜲'
AlchemicalSymbolForRegulusDash2\u{1f733}: '🜳'
AlchemicalSymbolForRegulusDash3\u{1f734}: '🜴'
AlchemicalSymbolForRegulusDash4\u{1f735}: '🜵'
AlchemicalSymbolForAlkali\u{1f736}: '🜶'
AlchemicalSymbolForAlkaliDash2\u{1f737}: '🜷'
AlchemicalSymbolForMarcasite\u{1f738}: '🜸'
AlchemicalSymbolForSalDashAmmoniac\u{1f739}: '🜹'
AlchemicalSymbolForArsenic\u{1f73a}: '🜺'
AlchemicalSymbolForRealgar\u{1f73b}: '🜻'
AlchemicalSymbolForRealgarDash2\u{1f73c}: '🜼'
AlchemicalSymbolForAuripigment\u{1f73d}: '🜽'
AlchemicalSymbolForBismuthOre\u{1f73e}: '🜾'
AlchemicalSymbolForTartar\u{1f73f}: '🜿'
AlchemicalSymbolForTartarDash2\u{1f740}: '🝀'
AlchemicalSymbolForQuickLime\u{1f741}: '🝁'
AlchemicalSymbolForBorax\u{1f742}: '🝂'
AlchemicalSymbolForBoraxDash2\u{1f743}: '🝃'
AlchemicalSymbolForBoraxDash3\u{1f744}: '🝄'
AlchemicalSymbolForAlum\u{1f745}: '🝅'
AlchemicalSymbolForOil\u{1f746}: '🝆'
AlchemicalSymbolForSpirit\u{1f747}: '🝇'
AlchemicalSymbolForTincture\u{1f748}: '🝈'
AlchemicalSymbolForGum\u{1f749}: '🝉'
AlchemicalSymbolForWax\u{1f74a}: '🝊'
AlchemicalSymbolForPowder\u{1f74b}: '🝋'
AlchemicalSymbolForCalx\u{1f74c}: '🝌'
AlchemicalSymbolForTutty\u{1f74d}: '🝍'
AlchemicalSymbolForCaputMortuum\u{1f74e}: '🝎'
AlchemicalSymbolForScepterOfJove\u{1f74f}: '🝏'
AlchemicalSymbolForCaduceus\u{1f750}: '🝐'
AlchemicalSymbolForTrident\u{1f751}: '🝑'
AlchemicalSymbolForStarredTrident\u{1f752}: '🝒'
AlchemicalSymbolForLodestone\u{1f753}: '🝓'
AlchemicalSymbolForSoap\u{1f754}: '🝔'
AlchemicalSymbolForUrine\u{1f755}: '🝕'
AlchemicalSymbolForHorseDung\u{1f756}: '🝖'
AlchemicalSymbolForAshes\u{1f757}: '🝗'
AlchemicalSymbolForPotAshes\u{1f758}: '🝘'
AlchemicalSymbolForBrick\u{1f759}: '🝙'
AlchemicalSymbolForPowderedBrick\u{1f75a}: '🝚'
AlchemicalSymbolForAmalgam\u{1f75b}: '🝛'
AlchemicalSymbolForStratumSuperStratum\u{1f75c}: '🝜'
AlchemicalSymbolForStratumSuperStratumDash2\u{1f75d}: '🝝'
AlchemicalSymbolForSublimation\u{1f75e}: '🝞'
AlchemicalSymbolForPrecipitate\u{1f75f}: '🝟'
AlchemicalSymbolForDistill\u{1f760}: '🝠'
AlchemicalSymbolForDissolve\u{1f761}: '🝡'
AlchemicalSymbolForDissolveDash2\u{1f762}: '🝢'
AlchemicalSymbolForPurify\u{1f763}: '🝣'
AlchemicalSymbolForPutrefaction\u{1f764}: '🝤'
AlchemicalSymbolForCrucible\u{1f765}: '🝥'
AlchemicalSymbolForCrucibleDash2\u{1f766}: '🝦'
AlchemicalSymbolForCrucibleDash3\u{1f767}: '🝧'
AlchemicalSymbolForCrucibleDash4\u{1f768}: '🝨'
AlchemicalSymbolForCrucibleDash5\u{1f769}: '🝩'
AlchemicalSymbolForAlembic\u{1f76a}: '🝪'
AlchemicalSymbolForBathOfMary\u{1f76b}: '🝫'
AlchemicalSymbolForBathOfVapours\u{1f76c}: '🝬'
AlchemicalSymbolForRetort\u{1f76d}: '🝭'
AlchemicalSymbolForHour\u{1f76e}: '🝮'
AlchemicalSymbolForNight\u{1f76f}: '🝯'
AlchemicalSymbolForDayDashNight\u{1f770}: '🝰'
AlchemicalSymbolForMonth\u{1f771}: '🝱'
AlchemicalSymbolForHalfDram\u{1f772}: '🝲'
AlchemicalSymbolForHalfOunce\u{1f773}: '🝳'
Methods
impl AlchemicalSymbols[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case